/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * AnimationEditorPanel.java
 *
 * Created on Feb 5, 2011, 3:48:00 PM
 */

package org.rwshop.swing.animation;

import org.rwshop.swing.common.scaling.ScalingManager;
import org.robokind.api.animation.editor.AnimationEditor;
import org.robokind.api.animation.editor.history.HistoryFactoryImpl;
import org.robokind.api.animation.editor.history.HistoryStack;
import org.robokind.api.common.utils.RKSource;
import org.robokind.api.common.utils.RKSource.SourceImpl;
import org.rwshop.swing.animation.menus.UIToolBar;
import static org.robokind.api.common.localization.Localizer.*;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class AnimationEditorPanel extends javax.swing.JPanel implements RKSource<AnimationEditor> {
    private AnimationEditor myController;
    private RKSource<HistoryStack> myHistorySource;
    private boolean myInitFlag;


    /** Creates new form AnimationEditorPanel */
    public AnimationEditorPanel() {
        myInitFlag = false;
        initComponents();
    }

    public void init(ScalingManager scalingManager){
        myAnimationPanel.init(scalingManager);
        myHistorySource = new SourceImpl<HistoryStack>();
        myToolBar.add(UIToolBar.FileToolBar(this, new HistoryFactoryImpl()));
        myToolBar.add(UIToolBar.HistoryToolBar(myHistorySource));
        myToolBar.add(UIToolBar.PlayerToolBar(this));
        myAnimationTable.setTableHeader($("animation.channels"));
        myChannelTable.setTableHeader($("motion.paths"));
        //myHistoryTable.setTableHeader($("history"));
        myInitFlag = true;
    }
    
    public void setController(AnimationEditor controller){
        if(!myInitFlag){
            throw new IllegalStateException(
                    "Panel must be initialized before using.");
        }
        myController = controller;
        HistoryStack hist = myController == null ? null : myController.getSharedHistory();
        myHistorySource.set(hist);
        myAnimationPanel.setController(myController);
        myAnimationTable.setController(myController);
        myChannelTable.setAnimationController(myController);
        if(myController == null){
            myChannelTable.setTableHeader($("motion.paths"));
        }else{
            myChannelTable.setTableHeader(myController.getName() + _$("motion.paths"));
        }
        mySelectedPathGrid.setAnimationController(myController);
        myHistoryTable.setHistory(myHistorySource.getValue());
        myTimelineOverviewPanel.setController(myController);
        repaint();
    }

    @Override
    public AnimationEditor getValue(){
        return myController;
    }

    @Override
    public void set(AnimationEditor controller){
        setController(controller);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jSplitPane1 = new javax.swing.JSplitPane();
        jPanel1 = new javax.swing.JPanel();
        splitLeftMenuTop = new javax.swing.JSplitPane();
        myAnimationTable = new org.rwshop.swing.animation.table.animation.AnimationTable();
        splitLeftMenuBottom = new javax.swing.JSplitPane();
        mySelectedPathGrid = new org.rwshop.swing.animation.table.motionpath.MotionPathTable();
        myChannelTable = new org.rwshop.swing.animation.table.channel.ChannelTable();
        jPanel2 = new javax.swing.JPanel();
        jSplitPane2 = new javax.swing.JSplitPane();
        myHistoryTable = new org.rwshop.swing.animation.table.history.HistoryTable();
        myEditorSplit = new javax.swing.JSplitPane();
        myTimelineOverviewPanel = new org.rwshop.swing.animation.timeline.TimelineOverviewPanel();
        myAnimationPanel = new org.rwshop.swing.animation.timeline.scroll.AnimationScrollPanel();
        myToolBar = new javax.swing.JToolBar();

        setPreferredSize(new java.awt.Dimension(814, 450));

        jSplitPane1.setBorder(javax.swing.BorderFactory.createEmptyBorder(1, 1, 1, 1));
        jSplitPane1.setDividerLocation(200);

        splitLeftMenuTop.setBorder(null);
        splitLeftMenuTop.setDividerLocation(150);
        splitLeftMenuTop.setOrientation(javax.swing.JSplitPane.VERTICAL_SPLIT);

        myAnimationTable.setBorder(javax.swing.BorderFactory.createEtchedBorder());
        splitLeftMenuTop.setLeftComponent(myAnimationTable);

        splitLeftMenuBottom.setBorder(null);
        splitLeftMenuBottom.setDividerLocation(150);
        splitLeftMenuBottom.setOrientation(javax.swing.JSplitPane.VERTICAL_SPLIT);

        mySelectedPathGrid.setBorder(javax.swing.BorderFactory.createEtchedBorder());
        splitLeftMenuBottom.setBottomComponent(mySelectedPathGrid);

        myChannelTable.setBorder(javax.swing.BorderFactory.createEtchedBorder());
        splitLeftMenuBottom.setLeftComponent(myChannelTable);

        splitLeftMenuTop.setRightComponent(splitLeftMenuBottom);

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(splitLeftMenuTop, javax.swing.GroupLayout.DEFAULT_SIZE, 199, Short.MAX_VALUE)
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(splitLeftMenuTop, javax.swing.GroupLayout.DEFAULT_SIZE, 417, Short.MAX_VALUE)
        );

        jSplitPane1.setLeftComponent(jPanel1);

        jSplitPane2.setBorder(null);
        jSplitPane2.setDividerLocation(450);
        jSplitPane2.setResizeWeight(1.0);

        myHistoryTable.setBorder(javax.swing.BorderFactory.createEtchedBorder());
        jSplitPane2.setRightComponent(myHistoryTable);

        myEditorSplit.setBorder(null);
        myEditorSplit.setDividerLocation(315);
        myEditorSplit.setOrientation(javax.swing.JSplitPane.VERTICAL_SPLIT);
        myEditorSplit.setResizeWeight(1.0);

        myTimelineOverviewPanel.setBorder(javax.swing.BorderFactory.createEtchedBorder());

        javax.swing.GroupLayout myTimelineOverviewPanelLayout = new javax.swing.GroupLayout(myTimelineOverviewPanel);
        myTimelineOverviewPanel.setLayout(myTimelineOverviewPanelLayout);
        myTimelineOverviewPanelLayout.setHorizontalGroup(
            myTimelineOverviewPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 446, Short.MAX_VALUE)
        );
        myTimelineOverviewPanelLayout.setVerticalGroup(
            myTimelineOverviewPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 93, Short.MAX_VALUE)
        );

        myEditorSplit.setRightComponent(myTimelineOverviewPanel);

        myAnimationPanel.setBorder(javax.swing.BorderFactory.createEtchedBorder());
        myEditorSplit.setLeftComponent(myAnimationPanel);

        jSplitPane2.setLeftComponent(myEditorSplit);

        javax.swing.GroupLayout jPanel2Layout = new javax.swing.GroupLayout(jPanel2);
        jPanel2.setLayout(jPanel2Layout);
        jPanel2Layout.setHorizontalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jSplitPane2, javax.swing.GroupLayout.DEFAULT_SIZE, 608, Short.MAX_VALUE)
        );
        jPanel2Layout.setVerticalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jSplitPane2, javax.swing.GroupLayout.DEFAULT_SIZE, 417, Short.MAX_VALUE)
        );

        jSplitPane1.setRightComponent(jPanel2);

        myToolBar.setFloatable(false);
        myToolBar.setRollover(true);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(myToolBar, javax.swing.GroupLayout.DEFAULT_SIZE, 814, Short.MAX_VALUE)
            .addComponent(jSplitPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 814, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addComponent(myToolBar, javax.swing.GroupLayout.PREFERRED_SIZE, 25, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSplitPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 419, Short.MAX_VALUE))
        );
    }// </editor-fold>//GEN-END:initComponents


    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JSplitPane jSplitPane1;
    private javax.swing.JSplitPane jSplitPane2;
    private org.rwshop.swing.animation.timeline.scroll.AnimationScrollPanel myAnimationPanel;
    private org.rwshop.swing.animation.table.animation.AnimationTable myAnimationTable;
    private org.rwshop.swing.animation.table.channel.ChannelTable myChannelTable;
    private javax.swing.JSplitPane myEditorSplit;
    private org.rwshop.swing.animation.table.history.HistoryTable myHistoryTable;
    private org.rwshop.swing.animation.table.motionpath.MotionPathTable mySelectedPathGrid;
    private org.rwshop.swing.animation.timeline.TimelineOverviewPanel myTimelineOverviewPanel;
    private javax.swing.JToolBar myToolBar;
    private javax.swing.JSplitPane splitLeftMenuBottom;
    private javax.swing.JSplitPane splitLeftMenuTop;
    // End of variables declaration//GEN-END:variables

}
