/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.rwshop.swing.animation.timeline.scroll;

import java.awt.Dimension;
import org.robokind.api.animation.editor.EditState;
import org.robokind.api.animation.editor.EditorListener;
import org.rwshop.swing.animation.timeline.AnimationTimelinePanel;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class AnimationResizeListener extends EditorListener{
    private AnimationTimelinePanel myPanel;

    /**
     *
     * @param panel
     */
    public AnimationResizeListener(AnimationTimelinePanel panel){
        myPanel = panel;
    }

    /**
     *
     * @param invoker
     * @param controller
     * @param index
     */
    public void itemAdded(Object invoker, Object controller, int index) {
        setSize();
    }

    /**
     *
     * @param invoker
     * @param controller
     * @param oldIndex
     * @param newIndex
     */
    public void itemMoved(Object invoker, Object controller, int oldIndex, int newIndex) {
        setSize();
    }

    /**
     *
     */
    public void setSize(){
        int animWidth = myPanel.getMinWidth();
        int min = myPanel.getMinimumSize().width;
        if(animWidth > min){
            int pref = myPanel.getPreferredSize().width;
            if(animWidth > pref){
                myPanel.setPreferredSize(new Dimension(animWidth, 0));
            }
            myPanel.setMinimumSize(new Dimension(animWidth, 0));
            myPanel.revalidate();
        }
    }

    /**
     *
     * @param invoker
     * @param controller
     * @param oldIndex
     * @param newIndex
     */
    public void selectionChanged(Object invoker, Object controller, int oldIndex, int newIndex) {}
    /**
     *
     * @param invoker
     * @param controller
     * @param index
     */
    public void itemRemoved(Object invoker, Object controller, int index) {}
    /**
     *
     * @param invoker
     * @param controller
     * @param state
     * @param value
     */
    public void stateChanged(Object invoker, Object controller, EditState state, boolean value) {}
    /**
     *
     * @param invoker
     * @param controller
     */
    public void structureChanged(Object invoker, Object controller){}
}